==> bbbasic-0.1.0.tgz: package/README.md <==
# BBBasic (Backbone Basic)#

<!-- 
> This material was originally posted [here](http://www.quora.com/What-is-Amazons-approach-to-product-development-and-product-management). It is reproduced here for posterities sake.

There is an approach called "working backwards" that is widely used at Amazon. They work backwards from the customer, rather than starting with an idea for a product and trying to bolt customers onto it. While working backwards can be applied to any specific product decision, using this approach is especially important when developing new products or features.

For new initiatives a product manager typically starts by writing an internal press release announcing the finished product. The target audience for the press release is the new/updated product's customers, which can be retail customers or internal users of a tool or technology. Internal press releases are centered around the customer problem, how current solutions (internal or external) fail, and how the new product will blow away existing solutions.

If the benefits listed don't sound very interesting or exciting to customers, then perhaps they're not (and shouldn't be built). Instead, the product manager should keep iterating on the press release until they've come up with benefits that actually sound like benefits. Iterating on a press release is a lot less expensive than iterating on the product itself (and quicker!).

If the press release is more than a page and a half, it is probably too long. Keep it simple. 3-4 sentences for most paragraphs. Cut out the fat. Don't make it into a spec. You can accompany the press release with a FAQ that answers all of the other business or execution questions so the press release can stay focused on what the customer gets. My rule of thumb is that if the press release is hard to write, then the product is probably going to suck. Keep working at it until the outline for each paragraph flows. 

Oh, and I also like to write press-releases in what I call "Oprah-speak" for mainstream consumer products. Imagine you're sitting on Oprah's couch and have just explained the product to her, and then you listen as she explains it to her audience. That's "Oprah-speak", not "Geek-speak".

Once the project moves into development, the press release can be used as a touchstone; a guiding light. The product team can ask themselves, "Are we building what is in the press release?" If they find they're spending time building things that aren't in the press release (overbuilding), they need to ask themselves why. This keeps product development focused on achieving the customer benefits and not building extraneous stuff that takes longer to build, takes resources to maintain, and doesn't provide real customer benefit (at least not enough to warrant inclusion in the press release).
 -->
 
## Simple App Design ##
  > A module designed to help budding young developers with no prior Backbone experience

## Summary ##
  > Get started with a few basic templates representing the major MVC components for a functional app.

## Problem ##
  > To take the confusion out of what's required to initialize and deploy a minimal website using the Backbone framework.

## Solution ##
  > Provides a Model, Controller, and View with a basic index.html to instantiate the representation of how each tie together to render a website with base functionality for deployment.

## Quote from You ##
  > Jumpstart your apps, worry about features another day.

## How to Get Started ##
  > Simply run npm install bbasic and download the module to get access. Then require('bbasic') in your js files.

## Customer Quote ##
  > 'I had no idea where to begin, but Backbone Basic took the mystery out of the process and made it easy'.

## Closing and Call to Action ##
  > After adjusting the templates to fit the individual needs of your app, get your server up and running and deploy to a service like [Azure](https://azure.microsoft.com/en-us/get-started/) or [Heroku](https://devcenter.heroku.com/start) to complete the process.

==> bbbasic-0.1.1.tgz: package/README.md <==
# BBBasic (Backbone Basic)#

<!-- 
> This material was originally posted [here](http://www.quora.com/What-is-Amazons-approach-to-product-development-and-product-management). It is reproduced here for posterities sake.

There is an approach called "working backwards" that is widely used at Amazon. They work backwards from the customer, rather than starting with an idea for a product and trying to bolt customers onto it. While working backwards can be applied to any specific product decision, using this approach is especially important when developing new products or features.

For new initiatives a product manager typically starts by writing an internal press release announcing the finished product. The target audience for the press release is the new/updated product's customers, which can be retail customers or internal users of a tool or technology. Internal press releases are centered around the customer problem, how current solutions (internal or external) fail, and how the new product will blow away existing solutions.

If the benefits listed don't sound very interesting or exciting to customers, then perhaps they're not (and shouldn't be built). Instead, the product manager should keep iterating on the press release until they've come up with benefits that actually sound like benefits. Iterating on a press release is a lot less expensive than iterating on the product itself (and quicker!).

If the press release is more than a page and a half, it is probably too long. Keep it simple. 3-4 sentences for most paragraphs. Cut out the fat. Don't make it into a spec. You can accompany the press release with a FAQ that answers all of the other business or execution questions so the press release can stay focused on what the customer gets. My rule of thumb is that if the press release is hard to write, then the product is probably going to suck. Keep working at it until the outline for each paragraph flows. 

Oh, and I also like to write press-releases in what I call "Oprah-speak" for mainstream consumer products. Imagine you're sitting on Oprah's couch and have just explained the product to her, and then you listen as she explains it to her audience. That's "Oprah-speak", not "Geek-speak".

Once the project moves into development, the press release can be used as a touchstone; a guiding light. The product team can ask themselves, "Are we building what is in the press release?" If they find they're spending time building things that aren't in the press release (overbuilding), they need to ask themselves why. This keeps product development focused on achieving the customer benefits and not building extraneous stuff that takes longer to build, takes resources to maintain, and doesn't provide real customer benefit (at least not enough to warrant inclusion in the press release).
 -->
 
## Simple App Design ##
  > A module designed to help budding young developers with no prior Backbone experience

## Summary ##
  > Get started with a few basic templates representing the major MVC components for a functional app.

## Problem ##
  > To take the confusion out of what's required to initialize and deploy a minimal website using the Backbone framework.

## Solution ##
  > Provides a few basic Models and Views with an index.html. The instantiation and representation of each are already coded for you along with comments on how they tie together to ultimately render a fully adjustable website with base functionality.

## Quote from You ##
  > Jumpstart your apps and get started with Backbone today.

## How to Get Started ##
  > Simply run `npm install bbbasic` and download the module to get access. 
  > Then require `bbbasic` in your js files.

## Customer Quote ##
  > I had no idea where to begin, but Backbone Basic took the mystery out of the process and made it easy. -First-Time User

## Closing and Call to Action ##
  > After adjusting the templates to fit the individual needs of your app, get your server up and running and deploy to a service like [Azure](https://azure.microsoft.com/en-us/get-started/) or [Heroku](https://devcenter.heroku.com/start) to complete the process.
